@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright (c) 2002-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -147,6 +147,14 @@ void SCIProwprepReset(
    SCIP_ROWPREP*         rowprep             /**< rowprep */
    );
 
+/** sets coefficient idx of rowprep */
+SCIP_EXPORT
+void SCIProwprepSetCoef(
+   SCIP_ROWPREP*         rowprep,            /**< rowprep */
+   int                   idx,                /**< index of coef to set */
+   SCIP_Real             newcoef             /**< new coefficient */
+   );
+
 /** adds constant value to side of rowprep */
 SCIP_EXPORT
 void SCIProwprepAddSide(
@@ -197,6 +205,7 @@ void SCIProwprepRecordModifications(
 #define SCIProwprepGetName(rowprep)   (rowprep)->name
 #define SCIProwprepGetNModifiedVars(rowprep) (rowprep)->nmodifiedvars
 #define SCIProwprepGetModifiedVars(rowprep) (rowprep)->modifiedvars
+#define SCIProwprepSetCoef(rowprep, idx, newcoef) ((rowprep)->coefs[idx] = (newcoef))
 #define SCIProwprepAddSide(rowprep, sideadd)  ((rowprep)->side += (sideadd))
 #define SCIProwprepAddConstant(rowprep, constant)  SCIProwprepAddSide(rowprep, -(constant))
 #define SCIProwprepSetSidetype(rowprep, sidetype_) (rowprep)->sidetype = sidetype_
