@@ -3,7 +3,7 @@
 /*                  This file is part of the program and library             */
 /*         SCIP --- Solving Constraint Integer Programs                      */
 /*                                                                           */
-/*  Copyright 2002-2022 Zuse Institute Berlin                                */
+/*  Copyright (c) 2002-2025 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -45,11 +45,6 @@
 #include "scip/type_conflict.h"
 #include "scip/type_cons.h"
 #include "scip/type_lp.h"
-#include "scip/type_result.h"
-#include "scip/type_retcode.h"
-#include "scip/type_scip.h"
-#include "scip/type_tree.h"
-#include "scip/type_var.h"
 
 #ifdef __cplusplus
 extern "C" {
